lambda_sequence: Determine lambda sequence

View source: R/cv_pensynth.R

lambda_sequenceR Documentation

Determine lambda sequence

Description

This function uses the weighted cross-product matrix (X1VX0) and Delta to determine the lambda sequence. This sequence will be exponentially increasing so it is easy to plot with a logarithmic x-axis

Usage

lambda_sequence(X1VX0, Delta, nlambda)

Arguments

X1VX0

the weighted cross-product matrix

Delta

the matching penalty matrix

nlambda

the number of lambda values

Details

The formula for the maximum lambda value was determined empirically, with an eye for the form of the quadratic program. In general, the max lambda should be so large that we are practically in "nearest-neighbour" matching territory. This formula ensures this for a wide range of input parameters.

Value

lambda sequence as a numeric vector

See Also

plot.cvpensynth()


pensynth documentation built on May 7, 2026, 9:06 a.m.