plot.cvpensynth: Plotting for hold-out validated penalized synthetic control...

View source: R/cv_pensynth.R

plot.cvpensynthR Documentation

Plotting for hold-out validated penalized synthetic control objects

Description

Displays a mean squared error curve and weights curve as a function of lambda, the penalization parameter.

Usage

## S3 method for class 'cvpensynth'
plot(x, treated_unit = 1, ...)

Arguments

x

a cvpensynth output object

treated_unit

integer index of the treated unit to display

...

additional arguments passed to plot()

Value

No return value, called for side effects

See Also

cv_pensynth() pensynth()


pensynth documentation built on May 7, 2026, 9:06 a.m.