plot.pensynthtest: Plotting a pensynth permutation object

View source: R/placebo_test.R

plot.pensynthtestR Documentation

Plotting a pensynth permutation object

Description

Plotting the reference distribution and the estimated treatement effect for the treated unit for the pensynth permutation test.

Usage

## S3 method for class 'pensynthtest'
plot(x, treated_unit = 1, ...)

Arguments

x

a pensynthtest object

treated_unit

integer index of the treated unit to display

...

additional parameters passed to plot

Value

No return value, called for side effects

See Also

base::plot()


pensynth documentation built on May 7, 2026, 9:06 a.m.