| predict.cvpensynth | R Documentation |
Matrix multiplies the values in newdata by the unit weights
extracted from the cvpensynth object to produce predicted
values.
## S3 method for class 'cvpensynth'
predict(object, newdata, lambda, ...)
object |
a fitted cvpensynth model |
newdata |
N_values * N_donors matrix of values for the donor units. |
lambda |
desired lambda value (defaults to optimal lambda) |
... |
ignored |
For a chosen lambda that is not in the list of tested lambdas in the cvpensynth object, the closest lambda (on the log scale) will be chosen.
a matrix (column vector) of predicted values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.