predict.pensynth: Create prediction from pensynth model

View source: R/pensynth.R

predict.pensynthR Documentation

Create prediction from pensynth model

Description

Matrix multiplies the values in newdata by the unit weights extracted from the pensynth object to produce predicted values.

Usage

## S3 method for class 'pensynth'
predict(object, newdata, ...)

Arguments

object

a fitted cvpensynth model

newdata

N_values * N_donors matrix of values for the donor units.

...

ignored

Value

a matrix (column vector) of predicted values


pensynth documentation built on May 7, 2026, 9:06 a.m.