standardize_X: Function to scale the X matrices in synthetic control

View source: R/standardization.R

standardize_XR Documentation

Function to scale the X matrices in synthetic control

Description

The default implementation of synthetic control first scales the X matrices using the mean and standard deviation of the X1 and X0 matrices together.

Usage

standardize_X(X1, X0)

Arguments

X1

the X1 matrix

X0

the X0 matrix

Details

See the pre-processing in Synth::synth().

Value

a list with X1 and X0 standardized.

See Also

base::scale()


pensynth documentation built on May 7, 2026, 9:06 a.m.