| lambda_sequence | R Documentation |
This function uses the weighted cross-product matrix (X1VX0) and Delta to determine the lambda sequence. This sequence will be exponentially increasing so it is easy to plot with a logarithmic x-axis
lambda_sequence(X1VX0, Delta, nlambda)
X1VX0 |
the weighted cross-product matrix |
Delta |
the matching penalty matrix |
nlambda |
the number of lambda values |
The formula for the maximum lambda value was determined empirically, with an eye for the form of the quadratic program. In general, the max lambda should be so large that we are practically in "nearest-neighbour" matching territory. This formula ensures this for a wide range of input parameters.
lambda sequence as a numeric vector
plot.cvpensynth()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.