| plot.cvpensynth | R Documentation |
Displays a mean squared error curve and weights curve as a function of lambda, the penalization parameter.
## S3 method for class 'cvpensynth'
plot(x, treated_unit = 1, ...)
x |
a |
treated_unit |
|
... |
additional arguments passed to |
No return value, called for side effects
cv_pensynth() pensynth()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.