| plot.pensynthtest | R Documentation |
Plotting the reference distribution and the estimated treatement effect for the treated unit for the pensynth permutation test.
## S3 method for class 'pensynthtest'
plot(x, treated_unit = 1, ...)
x |
a |
treated_unit |
|
... |
additional parameters passed to |
No return value, called for side effects
base::plot()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.