View source: R/standardization.R
| standardize_X | R Documentation |
The default implementation of synthetic control first scales the X matrices using the mean and standard deviation of the X1 and X0 matrices together.
standardize_X(X1, X0)
X1 |
the X1 matrix |
X0 |
the X0 matrix |
See the pre-processing in Synth::synth().
a list with X1 and X0 standardized.
base::scale()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.